import math
from .fn_fun import *

__all__ = ['cir', 'rad', 'fi', 'wi', 'ap', 'bp', 'cp', 'nuc1', 'nuc2']


def cir(d):
    c = round(d * math.pi, 2)
    s = round((math.pi / 4) * math.pow(d, 2), 2)
    return c, s  # for task_1


def rad(ab, bc, ac, bo):
    ld = round(math.sqrt(pow(ab, 2) - pow(bo, 2)), 2)
    r = round(bc / 2 * math.sqrt((2 * ab - bc) / (2 * ac + bc)), 2)
    return ld, r  # for task_2


def fi(x, a, b, i):
    k = math.tan(x + a) - math.log(i, math.fabs(b + 7))
    return k


def wi(c, x, d):
    k = math.pow(c, 5) * math.sqrt(pow(x, 2) + d * math.pow(math.e, 1.3))
    return k  # for task_3a


def ap():
    i = 3
    y = 100 * math.fabs(f5(i) + 50)
    return y


def bp():
    i = 3
    y = 150 * math.fabs(f6(i) + 100)
    return y


def cp():
    i = 3
    y = 200 * math.fabs(f7(i) + 135)
    return y  # for task_3b


def nuc1(k):
    a = f10(k) / k
    return a  # for task_7a


def nuc2(k):
    x = 0.242  # table Moivre-Laplace (0; 1)
    a = pow(-1, k) * ((f10(k) * pow(x, k)) / math.factorial(k))
    return a  # for task_7b



import math

__all__ = ['f5', 'f6', 'f7', 'f8', 'f9', 'f10', 'f11', 'f12', 'f13']


def f5(k):
    fn = math.cos(math.fabs(2 * k)) / 1.12 - math.cos(3 * k - 2) + 6.15
    return fn


def f6(k):
    fn = math.sin(k) * math.cos(pow(k, 2)) * math.sin(k + 1.4) + 5.14
    return fn


def f7(k):
    fn = math.fabs(math.sin(2 * k - 1.5) + 3 * math.sin(pow(k, 2))) + 2.38
    return fn  # for task_3


def f8(k):
    fn = math.cos(pow(k, 2)) * math.sin(2 * k - 1) + 4.29
    return fn


def f9(k):
    fn = math.cos(pow(k, 2) + 1) - math.fabs(math.sin(2 * k) - 5.76)
    return fn  # for task_6


def f10(k):
    fn = math.sin(k) - math.cos(pow(k, 3)) * math.sin(pow(k, 2) - 4.2) + 4.27
    return fn  # for task_7


def f11(k):
    fn = math.fabs(math.sin(12 * k) * math.cos(math.fabs(2 * k)) / 3) + 4.21
    return fn  # for task_8


def f12(k):
    fn = math.cos(pow(k, 3)) / 2.1 + math.cos(pow(k, 2)) / 1.1 - 8.3 * math.sin(3 * k + 1)
    return fn  # for task_9


def f13(k):
    fn = math.sin(pow(k, 2)) * math.cos(pow(k, 3)) - math.sin(k) + 5.2
    return fn  # for task_10
